rename SourceMgr::PrintError to PrintMessage.


git-svn-id: https://llvm.org/svn/llvm-project/llvm/trunk@73861 91177308-0d34-0410-b5e6-96231b3b80d8
diff --git a/lib/Support/SourceMgr.cpp b/lib/Support/SourceMgr.cpp
index 5460cb3..d789f10 100644
--- a/lib/Support/SourceMgr.cpp
+++ b/lib/Support/SourceMgr.cpp
@@ -90,12 +90,12 @@
 }
 
 
-void SourceMgr::PrintError(SMLoc ErrorLoc, const std::string &Msg) const {
+void SourceMgr::PrintMessage(SMLoc Loc, const std::string &Msg) const {
   raw_ostream &OS = errs();
   
   // First thing to do: find the current buffer containing the specified
   // location.
-  int CurBuf = FindBufferContainingLoc(ErrorLoc);
+  int CurBuf = FindBufferContainingLoc(Loc);
   assert(CurBuf != -1 && "Invalid or unspecified location!");
   
   PrintIncludeStack(getBufferInfo(CurBuf).IncludeLoc);
@@ -104,24 +104,24 @@
   
   
   OS << "Parsing " << CurMB->getBufferIdentifier() << ":"
-     << FindLineNumber(ErrorLoc, CurBuf) << ": ";
+     << FindLineNumber(Loc, CurBuf) << ": ";
   
   OS << Msg << "\n";
   
   // Scan backward to find the start of the line.
-  const char *LineStart = ErrorLoc.getPointer();
+  const char *LineStart = Loc.getPointer();
   while (LineStart != CurMB->getBufferStart() && 
          LineStart[-1] != '\n' && LineStart[-1] != '\r')
     --LineStart;
   // Get the end of the line.
-  const char *LineEnd = ErrorLoc.getPointer();
+  const char *LineEnd = Loc.getPointer();
   while (LineEnd != CurMB->getBufferEnd() && 
          LineEnd[0] != '\n' && LineEnd[0] != '\r')
     ++LineEnd;
   // Print out the line.
   OS << std::string(LineStart, LineEnd) << "\n";
   // Print out spaces before the caret.
-  for (const char *Pos = LineStart; Pos != ErrorLoc.getPointer(); ++Pos)
+  for (const char *Pos = LineStart; Pos != Loc.getPointer(); ++Pos)
     OS << (*Pos == '\t' ? '\t' : ' ');
   OS << "^\n";
 }
diff --git a/tools/llvm-mc/AsmLexer.cpp b/tools/llvm-mc/AsmLexer.cpp
index cf6a4a8..740215b 100644
--- a/tools/llvm-mc/AsmLexer.cpp
+++ b/tools/llvm-mc/AsmLexer.cpp
@@ -29,18 +29,14 @@
   return SMLoc::getFromPointer(TokStart);
 }
 
-void AsmLexer::PrintError(const char *Loc, const std::string &Msg) const {
-  SrcMgr.PrintError(SMLoc::getFromPointer(Loc), Msg);
-}
-
-void AsmLexer::PrintError(SMLoc Loc, const std::string &Msg) const {
-  SrcMgr.PrintError(Loc, Msg);
+void AsmLexer::PrintMessage(SMLoc Loc, const std::string &Msg) const {
+  SrcMgr.PrintMessage(Loc, Msg);
 }
 
 /// ReturnError - Set the error to the specified string at the specified
 /// location.  This is defined to always return asmtok::Error.
 asmtok::TokKind AsmLexer::ReturnError(const char *Loc, const std::string &Msg) {
-  PrintError(Loc, Msg);
+  SrcMgr.PrintMessage(SMLoc::getFromPointer(Loc), Msg);
   return asmtok::Error;
 }
 
@@ -203,10 +199,8 @@
       CurChar = getNextChar();
     }
     
-    if (CurChar == EOF) {
-      PrintError(TokStart, "unterminated string constant");
-      return asmtok::Eof;
-    }
+    if (CurChar == EOF)
+      return ReturnError(TokStart, "unterminated string constant");
 
     CurChar = getNextChar();
   }
diff --git a/tools/llvm-mc/AsmLexer.h b/tools/llvm-mc/AsmLexer.h
index c668e86..bad2cb9 100644
--- a/tools/llvm-mc/AsmLexer.h
+++ b/tools/llvm-mc/AsmLexer.h
@@ -89,8 +89,7 @@
   
   SMLoc getLoc() const;
   
-  void PrintError(const char *Loc, const std::string &Msg) const;
-  void PrintError(SMLoc Loc, const std::string &Msg) const;
+  void PrintMessage(SMLoc Loc, const std::string &Msg) const;
   
 private:
   int getNextChar();
diff --git a/tools/llvm-mc/AsmParser.cpp b/tools/llvm-mc/AsmParser.cpp
index 9c0b4ab..1940d76 100644
--- a/tools/llvm-mc/AsmParser.cpp
+++ b/tools/llvm-mc/AsmParser.cpp
@@ -16,6 +16,17 @@
 #include "llvm/Support/raw_ostream.h"
 using namespace llvm;
 
+bool AsmParser::Error(SMLoc L, const char *Msg) {
+  Lexer.PrintMessage(L, Msg);
+  return true;
+}
+
+bool AsmParser::TokError(const char *Msg) {
+  Lexer.PrintMessage(Lexer.getLoc(), Msg);
+  return true;
+}
+
+
 bool AsmParser::Run() {
   // Prime the lexer.
   Lexer.Lex();
@@ -34,8 +45,7 @@
 bool AsmParser::ParseStatement() {
   switch (Lexer.getKind()) {
   default:
-    Lexer.PrintError(Lexer.getLoc(), "unexpected token at start of statement");
-    return true;
+    return TokError("unexpected token at start of statement");
   case asmtok::EndOfStatement:
     Lexer.Lex();
     return false;
diff --git a/tools/llvm-mc/AsmParser.h b/tools/llvm-mc/AsmParser.h
index 5e1f6c6..66e1a9b 100644
--- a/tools/llvm-mc/AsmParser.h
+++ b/tools/llvm-mc/AsmParser.h
@@ -30,6 +30,8 @@
 private:
   bool ParseStatement();
   
+  bool Error(SMLoc L, const char *Msg);
+  bool TokError(const char *Msg);
 };
 
 } // end namespace llvm
diff --git a/tools/llvm-mc/llvm-mc.cpp b/tools/llvm-mc/llvm-mc.cpp
index 0acd78e..7d0c571 100644
--- a/tools/llvm-mc/llvm-mc.cpp
+++ b/tools/llvm-mc/llvm-mc.cpp
@@ -77,7 +77,7 @@
   while (Tok != asmtok::Eof) {
     switch (Tok) {
     default:
-      Lexer.PrintError(Lexer.getLoc(), "driver: unknown token");
+      Lexer.PrintMessage(Lexer.getLoc(), "driver: unknown token");
       Error = true;
       break;
     case asmtok::Error:
diff --git a/utils/TableGen/TGLexer.cpp b/utils/TableGen/TGLexer.cpp
index 976c123..6fe8d82 100644
--- a/utils/TableGen/TGLexer.cpp
+++ b/utils/TableGen/TGLexer.cpp
@@ -44,11 +44,11 @@
 
 
 void TGLexer::PrintError(const char *Loc, const std::string &Msg) const {
-  SrcMgr.PrintError(SMLoc::getFromPointer(Loc), Msg);
+  SrcMgr.PrintMessage(SMLoc::getFromPointer(Loc), Msg);
 }
 
 void TGLexer::PrintError(SMLoc Loc, const std::string &Msg) const {
-  SrcMgr.PrintError(Loc, Msg);
+  SrcMgr.PrintMessage(Loc, Msg);
 }
 
 
diff --git a/utils/TableGen/TableGen.cpp b/utils/TableGen/TableGen.cpp
index cb83cf3..038cde2 100644
--- a/utils/TableGen/TableGen.cpp
+++ b/utils/TableGen/TableGen.cpp
@@ -127,7 +127,7 @@
 static SourceMgr SrcMgr;
 
 void llvm::PrintError(SMLoc ErrorLoc, const std::string &Msg) {
-  SrcMgr.PrintError(ErrorLoc, Msg);
+  SrcMgr.PrintMessage(ErrorLoc, Msg);
 }
diff --git a/include/llvm/Support/SourceMgr.h b/include/llvm/Support/SourceMgr.h
index 53e7dd8..25775cb 100644
--- a/include/llvm/Support/SourceMgr.h
+++ b/include/llvm/Support/SourceMgr.h
@@ -107,10 +107,9 @@
   /// specified file.  This is not a fast method.
   unsigned FindLineNumber(SMLoc Loc, int BufferID = -1) const;
   
-  
-  /// PrintError - Emit an error message about the specified location with the
+  /// PrintMessage - Emit a message about the specified location with the
   /// specified string.
-  void PrintError(SMLoc ErrorLoc, const std::string &Msg) const;
+  void PrintMessage(SMLoc Loc, const std::string &Msg) const;
   
 private:
   void PrintIncludeStack(SMLoc IncludeLoc) const;